===============================
Zeus Python Client
===============================

.. image:: https://raw.githubusercontent.com/CiscoZeus/python-zeusclient/master/docs/images/zeus_logo.png

.. image:: https://travis-ci.org/CiscoZeus/python-zeusclient.svg
    :target: https://travis-ci.org/CiscoZeus/python-zeusclient

.. image:: https://coveralls.io/repos/CiscoZeus/python-zeusclient/badge.svg?branch=master
  :target: https://coveralls.io/r/CiscoZeus/python-zeusclient?branch=master

.. image:: https://img.shields.io/pypi/v/cisco-zeus.svg
        :target: https://pypi.python.org/pypi/cisco-zeus

.. image:: https://www.codacy.com/project/badge/6974aae737bf4dbda5f7b5dfeced4371
    :target: https://www.codacy.com/app/marc_1559/python-zeusclient


Python client for CiscoZeus.io. It allows a user to send and receive data to and from Zeus.

* Free software: Apache License
* Documentation: https://cisco-zeus.readthedocs.org.

Features
--------

* Send logs and metrics to Zeus
* Query both logs and metrics
